<a id="autonomy.replay.utils"></a>

# autonomy.replay.utils

Utils module.

<a id="autonomy.replay.utils.fix_address_books"></a>

#### fix`_`address`_`books

```python
def fix_address_books(build_dir: Path) -> None
```

Update address books in data dump to use them in replays.

<a id="autonomy.replay.utils.fix_config_files"></a>

#### fix`_`config`_`files

```python
def fix_config_files(build_dir: Path) -> None
```

Update config.toml in data dump to use them in replays.

